@@ -6,9 +6,9 @@ use warnings;
 our $VERSION = '0.10';
 
 my %config = (
-            'gimp' => '/opt/local/bin/gimp-2.10',
+            'gimptool' => '/opt/local/bin/gimptool-2.0',
             'gimpplugindir' => '/opt/local/lib/gimp/2.0/plug-ins',
-            'gimptool' => '/opt/local/bin/gimptool-2.0'
+            'gimp' => '/opt/local/bin/gimp-2.10'
           );
 
 
